Register

First visit to GardenStew? Learn more | Already a member? -> Sign in Not a member yet? -> Register
Become a GardenStew member, it's free!
- Free, unlimited access to all of our great features - Less advertisements! - Great friendships with like-minded people - More knowledge than you can shake a stick at
Please review our Terms and Conditions below before continuing. Thanks! Membership with GardenStew.com grants you access to our forums, our blog system, GardenStew PLANTS and a host of sub-features (such as the Private Messaging system). The Terms & Conditions are as follows: Note: unless specified explicitly all mentions of GardenStew.com below include GardenStew PLANTS also. As of 20th October 2009 'GardenStew PLANTS' is the new name of 'PlantStew'. All mentions of 'content' below mean text and images unless explicitly stated otherwise. - While every attempt is made to remove objectionable content as quickly as possible, it may not be possible to review every piece of content. Therefore you agree that all content posted on GardenStew.com express the views of the author and not the administrators, moderators or webmaster (except for content posted by these people) and hence will not be held liable. - You agree not to post any content that is illegal, libelous, defamatory, obscene, pornographic, harassing, threatening, invasive of another person's privacy, or a violation of copyright. - You agree that the webmaster, administrators and moderators reserve the right to remove, not remove, edit or move any content. User accounts can also be deactivated or deleted at any time with or without prior warning. - As a member you consent to have your data handled in accordance with our Privacy Policy. While we attempt to safeguard our data, the administrators and moderators cannot be held responsible for any hacking attempt that may lead to the data being compromised. You certify that you will not attempt to gain access to private member information (including passwords), nor will you attempt or assist with any nefarious activity against our servers. - By posting text on GardenStew.com, you grant us a license to display, edit, communicate to the public the submitted text (in whole or in part) worldwide. - By posting/uploading images you grant us a license to display the submitted images worldwide and consider them for redisplay in our Pic of the Month competition (where a thumbnail of the submitted images will be created and served from the GardenStew.com server). You retain full copyright over your images at all times. Images uploaded to GardenStew.com can be removed by the owner at any time. - GardenStew.com is advertiser supported. We reserve the right to publish ads on the same pages as content you post. - You agree to acknowledge that any content posted within GardenStew PLANTS is not necessarily posted by experts and as such may not be completely accurate. You agree that as a result of using such content that GardenStew.com/GardenStew PLANTS administrators, moderators and webmaster cannot be held liable for damage, injury or losses consequent or in relation with the use of this content. - You agree to adhere to the GardenStew Usage Rules and GardenStew PLANTS Usage Rules when performing any activity on the site. It is the sole responsibility of the individual member to check these Usage Rules for revisions from time to time. - You agree that you are over or exactly 13 years of age. - GardenStew.com may add to or otherwise modify the Terms & Conditions from time to time at its sole discretion. The Terms & Conditions will be available for review through a link at the bottom of each page throughout GardenStew.com. It is the sole responsibility of the individual member to check the Terms & Conditions for revisions from time to time. The current date of revision will be listed on the Terms & Conditions page. If you don't agree with a current revision of the Terms & Conditions you must a) discontinue your use of the GardenStew.com website and b) contact us to inform us that you wish to deactivate your account. YOUR CONTINUED USE OF GARDENSTEW.COM FOLLOWING ANY CHANGES TO THESE TERMS & CONDITIONS WILL SIGNIFY YOUR ACCEPTANCE OF ANY SUCH CHANGES I Agree To These Terms
back to top of page | Sponsored Links